@@ -1,6 +1,6 @@
 /*
  * backendz.h -- Internal interface exported by XBoard backend.c to zippy.c
- * $Id: backendz.h,v 1.10 1999/12/04 01:53:01 mann Exp $
+ * $Id: backendz.h,v 2.1 2003/10/27 19:21:00 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -52,26 +52,6 @@
 #include "common.h"
 #include "frontend.h"
 
-typedef struct _CPS {
-    char *which;
-    int maybeThinking;
-    ProcRef pr;
-    InputSourceRef isr;
-    int sendTime; /* 0=don't, 1=do, 2=test */
-    int sendDrawOffers;
-    char *twoMachinesColor; /* "white\n" or "black\n" */
-    char *program;
-    char *host;
-    char *dir;
-    struct _CPS *other;
-    char *initString;
-    int attention;
-    int offeredDraw; /* countdown */
-    int reuse;
-    char tidy[MSG_SIZ];
-    int matchWins;
-} ChessProgramState;
-
 extern long whiteTimeRemaining, blackTimeRemaining;
 extern int forwardMostMove;
 extern char star_match[STAR_MATCH_N][MSG_SIZ];
@@ -82,13 +62,11 @@ extern GameInfo gameInfo;
 extern void SendToICS P((char *s));
 extern int looking_at P((char *, int *, char *));
 extern void SendToProgram P((char *message, ChessProgramState *cps));
-extern void SendBoard P((ChessProgramState *cps, Board board,
-			 int/*boolean*/ blackPlaysFirst));
+extern void SendBoard P((ChessProgramState *cps, int moveNum));
 void SendTimeRemaining P((ChessProgramState *cps,
 			  int/*boolean*/ machineWhite));
 
-extern ChessProgramState first, second;
-
 extern char ics_handle[];
+extern char *ics_prefix;
 
 #endif
